.. |logo| image:: _static/logo01.svg
	:width: 300

|logo|

bewegung - a versatile video renderer
=====================================

*/bəˈveːɡʊŋ/* - German, noun, feminine: `motion / movement / animation`_

.. _motion / movement / animation: https://dict.leo.org/englisch-deutsch/bewegung

.. |docs_master| image:: https://readthedocs.org/projects/bewegung/badge/?version=latest&style=flat-square
	:target: https://bewegung.readthedocs.io/en/latest/
	:alt: Documentation Status: master / release
.. |license| image:: https://img.shields.io/pypi/l/bewegung.svg?style=flat-square
	:target: https://github.com/pleiszenburg/bewegung/blob/master/LICENSE
	:alt: LGPL 2.1
.. |status| image:: https://img.shields.io/pypi/status/bewegung.svg?style=flat-square
	:target: https://github.com/pleiszenburg/bewegung/issues
	:alt: Project Development Status
.. |pypi_version| image:: https://img.shields.io/pypi/v/bewegung.svg?style=flat-square
	:target: https://pypi.python.org/pypi/bewegung
	:alt: pypi version
.. |conda_version| image:: https://img.shields.io/conda/vn/conda-forge/bewegung.svg?style=flat-square
	:target: https://anaconda.org/conda-forge/bewegung
	:alt: conda version
.. |pypi_versions| image:: https://img.shields.io/pypi/pyversions/bewegung.svg?style=flat-square
	:target: https://pypi.python.org/pypi/bewegung
	:alt: Available on PyPi - the Python Package Index
.. |chat| image:: https://img.shields.io/matrix/bewegung:matrix.org.svg?style=flat-square
	:target: https://matrix.to/#/#bewegung:matrix.org
	:alt: Matrix Chat Room
.. |mailing_list| image:: https://img.shields.io/badge/mailing%20list-groups.io-8cbcd1.svg?style=flat-square
	:target: https://groups.io/g/bewegung-dev
	:alt: Mailing List

|docs_master| |license| |status| |pypi_version| |conda_version| |pypi_versions| |chat| |mailing_list|

.. warning::

    ``bewegung``'s development status is "**well-tested alpha**". Its API should not be considered stable until the project is labeled "beta" or better.

.. toctree::
   :maxdepth: 2
   :caption: Introduction

   about
   installation
   getting_started
   gallery

.. toctree::
   :maxdepth: 2
   :caption: Reference

   canvas
   anatomy
   algebra

.. toctree::
   :maxdepth: 2
   :caption: Advanced

   performance
   debug
   changes
   support

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
